---------------------------------------------------
---------------------------------------------------
--  Easy 1 Processor Architecture				 --
--  University of Puerto Rico					 --
--  Mayaguez Campus								 --
--	Department of Computer Engineering			 --
-- 												 --
--	Copyright (c) 2003							 --
--	All rigths reserved.						 --
--										   		 --
--	Prof. Bienvenido Vlez						 --
--	Abdiel Avils								 --
--	Rafael S. Garca							 --
--	Nesmary Hernndez 							 --
-- 	Carlos Prez								 --
---------------------------------------------------
---------------------------------------------------
-- 	[easy1_computer.vhd]
--	Easy 1 Computer
--	This module describes the processor and memory
--	integration. The Easy 1 computer contains an
--	Easy 1 processor conected with a memory
--	module. The external inputs to this module are
--	the clock source and the reset button.
---------------------------------------------------	
---------------------------------------------------
--	Libraries declarations
library ieee;
use ieee.std_logic_1164.all; 
use easy1_package.all;
--
---------------------------------------------------
--	Entity declaration
--	@clock  	   	- clock source
--	@reset     		- reset signal
--
entity easy1_computer is
	
	port(
		clock 	: in std_logic:='0';
		reset 	: in std_logic:='0'
		);
	
end easy1_computer;
--
----------------------------------------------------
--	Architecture declaration
--	Signals :
--		@tmp_data_in	- data from memory to processor
--		@tmp_data_out	- data from processor to memory
--		@tmp_addr		- memory address
--		@tmp_op			- memory operation
--
--	Components :
--		@easy1_processor	- Easy 1 Processor
--		@easy1_RAM		 	- Easy 1 Memory
--
architecture arq of easy1_computer is
	
	component easy1_processor
		port (					  		
			address_bus  	: out std_logic_vector(15 downto 0):=X"0000";
			data_in	    	: in std_logic_vector(15 downto 0):=X"0000";
			data_out		: out std_logic_vector(15 downto 0):=X"0000";
			control_bus  	: out std_logic_vector(1 downto 0):="00";
			clock		 	: in std_logic:='0';
			reset        	: in std_logic:='0'
			);
	end component easy1_processor;
	
	component easy1_RAM
		port(
			clock		:	in std_logic:='0';	
			mem_op		:	in std_logic_vector(1 downto 0):="00";
			Addr		:	in std_logic_vector(15 downto 0):=X"0000";
			data_in		: 	in std_logic_vector(15 downto 0):=X"0000";
			data_out	: 	out std_logic_vector(15 downto 0):=X"0000"
			);
	end component easy1_RAM; 
	
	signal tmp_data_in	: std_logic_vector(15 downto 0):=X"0000";
	signal tmp_data_out	: std_logic_vector(15 downto 0):=X"0000";
	signal tmp_addr		: std_logic_vector(15 downto 0):=X"0000";
	signal tmp_op		: std_logic_vector(1 downto 0):="00";
	
begin	   
	
	--	Easy 1 Processor
	easy1: easy1_processor
	port map (
		address_bus => tmp_addr,
		data_in => tmp_data_in,
		data_out => tmp_data_out,
		control_bus => tmp_op,
		clock => clock,
		reset => reset
		);
		
	--	Easy 1 Memory Module
	RAM0: easy1_RAM
	port map(
		clock => clock,
		mem_op => tmp_op,
		Addr => tmp_addr,
		data_in => tmp_data_out,
		data_out => tmp_data_in
		);
	
end arq;
---------------------------------------------------	
---------------------------------------------------